#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 base-prelude
version:              1.4
visibility:           public
id:                   base-prelude-1.4-6gvPEnwZlZz39pkAigtkjO
key:                  base-prelude-1.4-6gvPEnwZlZz39pkAigtkjO
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/base-prelude 
synopsis:
    The most complete prelude formed solely from the "base" package

description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.

    This package will never have any dependencies other than \"base\".

    /Versioning policy/

    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.

category:             Prelude
abi:                  32a22290b7acb8faa3301b45dc878755
exposed:              True
exposed-modules:      BasePrelude
import-dirs:          /usr/lib/ghc-8.10.5/site-local/base-prelude-1.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/base-prelude-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/base-prelude-1.4
hs-libraries:         HSbase-prelude-1.4-6gvPEnwZlZz39pkAigtkjO
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock

haddock-html:         /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

